.. Django-rflatpages documentation master file, created by
   sphinx-quickstart on Fri Sep  7 09:39:01 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Django-rflatpage's documentation!
============================================

Contents:

.. toctree::
   :maxdepth: 2



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

